#ifndef LIBSTP_C_H
#define LIBSTP_C_H

#ifdef __cplusplus
extern "C" {
#endif

#include <stdbool.h> // For bool type
#include <stdarg.h> // For va_list

#define PROGRAMS_PATH "/usr/bin/"

#define CLI 0
#define TUI 1
#define GUI 2
#define Menu 3

#define MAX_SCRIPTS 128
#define MAX_PATH 1024

typedef struct {
    char name[256];
    char path[MAX_PATH];
} Script;

// Function declarations
char *strlwr(char *str);
int runCommand(const char* format, ...);
bool commandExists(const char* command);
bool installProgram(const char *command);
int getMenuOption(int maxOption);
void extractOSVersion(char *version);
void extractLinuxDistro(char *distro);
bool installWithPackageManager(const char* packageName, const char* packageManager);
bool uninstallWithFlatpak(const char* packageName);
bool uninstallWithDNF(const char* packageName);
bool uninstallWithDNF5(const char* packageName);
bool uninstallWithSnap(const char* packageName);
bool searchWithFlatpak(const char* packageName);
bool searchWithDNF(const char* packageName);
bool searchWithDNF5(const char* packageName);
bool searchWithSnap(const char* packageName);
bool isValidPackageName(const char *packageName);
int checkProgramExists(const char* programName);
int shouldShowNotice_tp();
int shouldShowNotice_beta();
void autostart_beta();
void saveUserResponse_tp(char response);
char *getSecurePasswordSTP();
char* getVersion(const char* programName);
void set_log_path();
int listScripts(const char* directory, Script scripts[]);
void displayScriptMenu(Script scripts[], int scriptCount);
void executeScript(const char* scriptPath);
void setConfigFile(const char* path);
const char* getConfigFile(void);
bool hasConfigFile(void);

#ifdef __cplusplus
}
#endif

#endif
